@@ -1,6 +1,6 @@
 package GappX::FormTraits::Meta::Widget::Custom::Trait::ZipCodeEntry;
 {
-  $GappX::FormTraits::Meta::Widget::Custom::Trait::ZipCodeEntry::VERSION = '0.204';
+  $GappX::FormTraits::Meta::Widget::Custom::Trait::ZipCodeEntry::VERSION = '0.300';
 }
 
 use Moose::Role;
@@ -14,7 +14,7 @@ around BUILDARGS => sub {
 # returns the value of the widget
 around 'get_field_value' => sub {
     my ( $orig, $self, @args ) = @_;
-    $self->gobject->get_text eq '' ? undef : $self->gtk_widget->get_text;
+    $self->gobject->get_text eq '' ? undef : $self->gobject->get_text;
 };
 
 around 'set_field_value' => sub {
@@ -25,7 +25,7 @@ around 'set_field_value' => sub {
 
 package Gapp::Meta::Widget::Custom::Trait::ZipCodeEntry;
 {
-  $Gapp::Meta::Widget::Custom::Trait::ZipCodeEntry::VERSION = '0.204';
+  $Gapp::Meta::Widget::Custom::Trait::ZipCodeEntry::VERSION = '0.300';
 }
 sub register_implementation { 'GappX::FormTraits::Meta::Widget::Custom::Trait::ZipCodeEntry' };
 
